@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from .api.companies_api import CompaniesApi
+#   from .api.api_api import ApiApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,6 +14,7 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
+from openapi_client.api.api_api import ApiApi
 from openapi_client.api.companies_api import CompaniesApi
 from openapi_client.api.machines_api import MachinesApi
 from openapi_client.api.telemetry_api import TelemetryApi
